@@ -2,9 +2,9 @@
 The `FindOutputs` action.
 """
 
-import enum
 import hashlib
 import logging
+import re
 import shutil
 from pathlib import Path
 from typing import List, Optional
@@ -12,28 +12,14 @@ from typing import List, Optional
 from pydantic import BaseModel
 
 from blight.action import Action
+from blight.constants import OUTPUT_SUFFIX_KIND_MAP, OUTPUT_SUFFIX_PATTERN_MAP
+from blight.enums import OutputKind
 from blight.tool import CC, CXX, LD, Tool
 from blight.util import flock_append
 
 logger = logging.getLogger(__name__)
 
 
-@enum.unique
-class OutputKind(str, enum.Enum):
-    """
-    A collection of common output kinds for build tools.
-
-    This enumeration is not exhaustive.
-    """
-
-    Object: str = "object"
-    SharedLibrary: str = "shared"
-    StaticLibrary: str = "static"
-    Executable: str = "executable"
-    KernelModule: str = "kernel"
-    Unknown: str = "unknown"
-
-
 class Output(BaseModel):
     """
     Represents a single output from a tool.
@@ -44,6 +30,14 @@ class Output(BaseModel):
     The kind of output.
     """
 
+    prenormalized_path: str
+    """
+    The path to the output, as passed directly to the tool itself.
+
+    This copy of the path may be relative; consumers should prefer
+    `path` for an absolute copy.
+    """
+
     path: Path
     """
     The path to the output, as created by the tool.
@@ -83,29 +77,6 @@ class OutputsRecord(BaseModel):
         json_encoders = {Tool: lambda t: t.asdict()}
 
 
-OUTPUT_SUFFIX_KIND_MAP = {
-    ".o": OutputKind.Object,
-    ".obj": OutputKind.Object,
-    ".so": OutputKind.SharedLibrary,
-    ".dylib": OutputKind.SharedLibrary,
-    ".dll": OutputKind.SharedLibrary,
-    ".a": OutputKind.StaticLibrary,
-    ".lib": OutputKind.StaticLibrary,
-    "": OutputKind.Executable,
-    ".exe": OutputKind.Executable,
-    ".bin": OutputKind.Executable,
-    ".elf": OutputKind.Executable,
-    ".com": OutputKind.Executable,
-    ".ko": OutputKind.KernelModule,
-    ".sys": OutputKind.KernelModule,
-}
-"""
-A mapping of common output suffixes to their (expected) file kinds.
-
-This mapping is not exhaustive.
-"""
-
-
 class FindOutputs(Action):
     def before_run(self, tool: Tool) -> None:
         outputs = []
@@ -120,7 +91,19 @@ class FindOutputs(Action):
             else:
                 kind = OUTPUT_SUFFIX_KIND_MAP.get(output_path.suffix, OutputKind.Unknown)
 
-            outputs.append(Output(kind=kind, path=output_path))
+                # Last attempt: try some common patterns for output kinds if we can't
+                # match the suffix precisely.
+                if kind == OutputKind.Unknown:
+                    kind = next(
+                        (
+                            k
+                            for (p, k) in OUTPUT_SUFFIX_PATTERN_MAP.items()
+                            if re.match(p, str(output_path))
+                        ),
+                        OutputKind.Unknown,
+                    )
+
+            outputs.append(Output(prenormalized_path=output, kind=kind, path=output_path))
 
         self._outputs = outputs
 
